@@ -14,7 +14,7 @@ import urllib.parse
 from botocore.exceptions import ClientError, EndpointConnectionError
 from botocore.config import Config
 
-from dragoneye.cloud_scanner.aws.aws_scan_request import AwsCloudScanSettings
+from dragoneye.cloud_scanner.aws.aws_scan_settings import AwsCloudScanSettings
 from dragoneye.cloud_scanner.base_cloud_scanner import BaseCloudScanner
 from dragoneye.utils.app_logger import logger
 from dragoneye.utils.misc_utils import get_dynamic_values_from_files, custom_serializer, make_directory, init_directory, load_yaml, snakecase, \
@@ -396,13 +396,23 @@ class AwsScanner(BaseCloudScanner):
         return params
 
     @staticmethod
-    def _fill_simple_params(param_groups, name, value):
+    def _fill_simple_params(param_groups, name, value, parameter: dict):
         if not param_groups:
             param_groups = [{name: value}]
             return param_groups
         else:
+            additional_param_group: List[dict] = []
             for param_group in param_groups:
-                param_group[name] = value
+                if "Values" in parameter:
+                    for val in value:
+                        param: dict = param_group.copy()
+                        param[name] = val
+                        additional_param_group.append(param)
+                else:
+                    param_group[name] = value
+            if additional_param_group:
+                param_groups.clear()
+                param_groups.extend(additional_param_group)
             return param_groups
 
     @staticmethod
@@ -456,11 +466,11 @@ class AwsScanner(BaseCloudScanner):
         param_groups = []
         for parameter in runner.get("Parameters", []):
             name = parameter["Name"]
-            value = parameter["Value"]
+            value = parameter.get("Value") or parameter.get("Values")
             is_dynamic = "|" in value
             parameter_keys.add(name)
             if not is_dynamic:
-                param_groups = self._fill_simple_params(param_groups, name, value)
+                param_groups = self._fill_simple_params(param_groups, name, value, parameter)
             else:
                 group = parameter.get("Group", False)
                 param_groups = self._fill_dynamic_params(param_groups, name, value, group, account_dir, region)
